DROP TABLE	registro;
DROP TABLE	motoristaCaminhao;
DROP TABLE	Cartao;
DROP TABLE	Contrata;
DROP TABLE	Carregar;
DROP TABLE	Carga;
DROP TABLE	Dirige;
DROP TABLE	Contrato;
DROP TABLE	TelefoneCliente;
DROP TABLE	Cliente;
DROP TABLE	Caminhao;
DROP TABLE	Auxiliar;
DROP TABLE	Motorista;
DROP TABLE	TelefoneFuncionario;
ALTER TABLE	Filial DROP COLUMN cpf_chefe;
DROP TABLE	Funcionario;
DROP TABLE	Filial;

CREATE TABLE filial (
	codigo NUMBER,
	nome VARCHAR2(30) NOT NULL,
    CEP character(9),
	Complemento varchar2(30),
	CONSTRAINT filial_pk PRIMARY KEY (codigo)
);

CREATE TABLE funcionario (
	codigo_filial NUMBER,
	CPF character(14) NOT NULL,
	CPF_supervisor character(14),
	salario NUMBER,
    data_Nascimento DATE,
    Nome VARCHAR2(30),
	CONSTRAINT funcionario_pk PRIMARY KEY (CPF),
	CONSTRAINT filial_funcionario_fk FOREIGN KEY (codigo_filial) REFERENCES filial (codigo)
);

ALTER TABLE filial
ADD cpf_chefe
CONSTRAINT cpf_chefe_fk REFERENCES funcionario(CPF);

CREATE TABLE TelefoneFuncionario (
	CPF_funcionario character(14) NOT NULL,
	telefone VARCHAR2(14) NOT NULL,
	CONSTRAINT telefonefuncionario_pk PRIMARY KEY (telefone, CPF_funcionario),
	CONSTRAINT funcionario_TelFunc_fk FOREIGN KEY (CPF_funcionario) REFERENCES funcionario(CPF)
);

CREATE TABLE Motorista (
	CPF_funcionario character(14) NOT NULL,
	habilitacao character(1) NOT NULL,
	CONSTRAINT motorista_pk PRIMARY KEY (CPF_funcionario),
   	CONSTRAINT funcionario_motorista_fk FOREIGN KEY (CPF_funcionario) REFERENCES funcionario(CPF)
);

CREATE TABLE Auxiliar (
	CPF_funcionario character(14) NOT NULL,
	Escolaridade VARCHAR2(30) NOT NULL,
	CONSTRAINT Auxiliar_pk PRIMARY KEY (CPF_funcionario),
	CONSTRAINT funcionario_auxiliar_fk FOREIGN KEY (CPF_funcionario) REFERENCES funcionario(CPF)
);


CREATE TABLE Caminhao (
	codigo_filial NUMBER,
	Placa character(8) NOT NULL,
	quilometragem FLOAT,
    CONSTRAINT placa_pk PRIMARY KEY (placa),
	CONSTRAINT filial_caminhao_fk FOREIGN KEY (codigo_filial) REFERENCES filial(codigo)
);

CREATE TABLE Cliente (
	nome varchar2(30),
	CNPJ character(18) NOT NULL,
    CEP character(9) NOT NULL,
    complemento varchar2(30) NOT NULL,
    CONSTRAINT cliente_pk PRIMARY KEY (cnpj)
);

CREATE TABLE TelefoneCliente (
	CNPJ_cliente character(18) NOT NULL,
	telefone VARCHAR2(14) NOT NULL,
	CONSTRAINT telefonecliente_pk PRIMARY KEY (telefone, CNPJ_cliente),
	CONSTRAINT cliente_TelCli_fk FOREIGN KEY (CNPJ_cliente) REFERENCES cliente(CNPJ)
);

CREATE TABLE Contrato(
    codigo NUMBER,
    CONSTRAINT Contrato_pk PRIMARY KEY (codigo)
);

CREATE TABLE Dirige(
    CPF_motorista character(14),
    placa_caminhao character(8),
    Data_inicio Date,
    Data_fim Date,
    CONSTRAINT Dirige_pk PRIMARY KEY (CPF_motorista, placa_caminhao, Data_inicio),
    CONSTRAINT motorista_Dirige_fk FOREIGN KEY (CPF_motorista) REFERENCES motorista(CPF_funcionario),
    CONSTRAINT caminhao_Dirige_fk FOREIGN KEY (placa_caminhao) REFERENCES caminhao(placa)  
);

CREATE TABLE Carga(
  codigo NUMBER,
  CNPJ_cliente character(18),
  codigo_contrato NUMBER,
  tipo varchar2(30) NOT NULL, 
  peso FLOAT,
  tamanho FLOAT,
  CEPdestino character(9) NOT NULL,
  complementoDestino varchar2(30) NOT NULL,
  CONSTRAINT Carga_pk PRIMARY KEY (codigo, CNPJ_cliente, codigo_contrato),
  CONSTRAINT cliente_carga_fk FOREIGN KEY (CNPJ_cliente) REFERENCES cliente(CNPJ),
  CONSTRAINT contrato_carga_fk FOREIGN KEY (codigo_contrato) REFERENCES contrato(codigo)
);

 CREATE TABLE Carregar(
   Codigo_carga NUMBER, 
   Placa_caminhao character(8), 
   CPF_auxiliar character(14),
   Carga_CNPJ_cliente character(18),
   carga_codigo_contrato NUMBER,
   CONSTRAINT Carregar_pk PRIMARY KEY (Codigo_carga, Placa_caminhao, CPF_auxiliar, Carga_CNPJ_cliente, carga_codigo_contrato),
   CONSTRAINT carga_carregar_fk FOREIGN KEY (codigo_carga, Carga_CNPJ_cliente, carga_codigo_contrato) REFERENCES carga(codigo, CNPJ_cliente, codigo_contrato),
   CONSTRAINT caminhao_carregar_fk FOREIGN KEY (placa_caminhao) REFERENCES caminhao(placa),
   CONSTRAINT auxiliar_carregar_fk FOREIGN KEY (cpf_auxiliar) REFERENCES auxiliar(cpf_funcionario)
);
 
 

CREATE TABLE Contrata(
   CNPJ_cliente character(18),
   Codigo_contrato NUMBER,
   Codigo_filial NUMBER,
   data_contrata date,
   CONSTRAINT contrata_pk PRIMARY KEY (CNPJ_cliente, Codigo_contrato, Codigo_filial, data_contrata),
   CONSTRAINT cliente_contrata_fk FOREIGN KEY (CNPJ_cliente) REFERENCES cliente(CNPJ),
   CONSTRAINT contrato_contrata_fk FOREIGN KEY (codigo_contrato) REFERENCES contrato(codigo),
   CONSTRAINT filial_contrata_fk FOREIGN KEY (codigo_filial) REFERENCES filial(codigo)
 );

CREATE TABLE Cartao(
    Numero character(19),
    codigo_filial NUMBER,
    CONSTRAINT cartao_pk PRIMARY KEY (Numero),
    CONSTRAINT filial_cartao_fk FOREIGN KEY (codigo_filial) REFERENCES filial(codigo)
);

CREATE TABLE MotoristaCaminhao(
    Numero_cartao character(19),
    CPF_motorista character(14),
    placa_caminhao character(8),
    CONSTRAINT MotoristaCaminhao_pk PRIMARY KEY (Numero_cartao, CPF_motorista, placa_caminhao),
    CONSTRAINT motorista_MotoCami_fk FOREIGN KEY (CPF_motorista) REFERENCES Motorista(CPF_funcionario),
    CONSTRAINT caminhao_MotoCami_fk FOREIGN KEY (placa_caminhao) REFERENCES Caminhao(placa),
    CONSTRAINT cartao_MotoCami_fk FOREIGN KEY (numero_cartao) REFERENCES Cartao(numero)
);


CREATE TABLE Registro (
    data_registro DATE,
    codigo_filial NUMBER,
    valor FLOAT,
    CONSTRAINT registro_pk PRIMARY KEY (data_registro),
    CONSTRAINT filial_registro_fk FOREIGN KEY (codigo_filial) REFERENCES filial(codigo)
);



